<template>
  <AnalyticsCard
    :is-loading="isLoading"
    :title="title"
  >
    <div class="size-full p-4">
      <PolarAreaChart
        :label="label"
        :labels="chartLabels"
        :value="chartValues"
      />
    </div>
  </AnalyticsCard>
</template>

<script lang="ts" setup>
import PolarAreaChart, { type DataSet } from "@/js/contexts/shared/ui/components/charts/PolarAreaChart.vue";
import { snakeCase } from "lodash-es";
import AnalyticsCard from "@/js/contexts/shared/ui/components/analytics/AnalyticsCard.vue";

const props = defineProps<{
  isLoading: boolean;
  title: string;
  prefix: string;
  label: string;
  data: { label: string; value: number; color: string; percentage: number }[] | undefined;
}>();

const { t } = useI18n();

const chartLabels = computed<string[]>(() => props.data?.map((item) => t(`${props.prefix}.${snakeCase(item.label)}`)) ?? []);
const chartValues = computed<DataSet>(() => ({ values: props.data?.map((item) => item.value) ?? [], colors: props.data?.map((item) => item.color) ?? [] }));
</script>
